#
# web.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-03-10.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ostruct'
require 'rexml/document'
require 'rexml/streamlistener'

include REXML

module DatabaseClient
  module Reporter
    class EWB
      include StreamListener

      def initialize(output)
        @xctx = Array.new
        @xhit = nil
        @xhsps = nil
        @xhsp = nil
        @out = output
      end
  
      def tag_start(name, attributes)
        if name == "hit"
          @xhit = attributes
          @xhsps = Array.new
        elsif name == "alignment"
          @xhsp = Hash.new
        elsif @xhsp
          attributes.each_pair do |key, val|
            @xhsp[name+':'+key] = val
          end
        end
        @xctx.push name
      end
  
      def text(text)
        if @xhsp
          @xhsp[@xctx.last] = text
        end
      end

      def tag_end(name)
        @xctx.pop
        if name == "hit"
          show_hit(@xhit, @xhsps)
          @xhit = nil
          @xhsps = nil
        elsif name == "alignment"
          @xhsps << @xhsp
          @xhsp = nil
        end
      end
  
      def show_hit(xhit, xhsps)
        @out.context "hit" do |hit|
          hit.property 'identifier', xhit['ac'] || xhit['id']
    	    hit.property 'database', xhit['database']
      
    	    hit.property 'description', xhit['description']
    	    hit.property 'length', xhit['length']
	        
    	    hit.spacer
          xhsps.each do |xhsp| hit.context "hsp" do |hsp|
            hsp.property 'hseq', xhsp['matchSeq']
            hsp.property 'qseq', xhsp['querySeq']
            
            strands = xhsp['strand'].split('/') if xhsp['strand']
            
            if strands && strands[0] == 'minus'
              hsp.property 'hloc', "complement("+xhsp['matchSeq:start']+".."+xhsp['matchSeq:end']+")"
            else
              hsp.property 'hloc', xhsp['matchSeq:start']+".."+xhsp['matchSeq:end']
            end
        
            if strands && strands[1] == 'minus'
              hsp.property 'qloc', "complement("+xhsp['querySeq:start']+".."+xhsp['querySeq:end']+")"
            else
              hsp.property 'qloc', xhsp['querySeq:start']+".."+xhsp['querySeq:end']
            end
        
            hsp.property 'positives', xhsp['positive']
            hsp.property 'identity', xhsp['identity']
            hsp.property 'length', xhsp['querySeq'].length
            hsp.property 'rscore', xhsp['score']
            hsp.property 'bscore', xhsp['bits']
            hsp.property 'evalue', xhsp['expectation']
          end; end
        end
      end
      
    end # NCB
  end # Reporter
end # DatabaseClient