#
# ncb.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2007-11-05.
# Copyright 2007 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ostruct'
require 'rexml/document'
require 'rexml/streamlistener'

include REXML

module DatabaseClient
  module Reporter
    class NCB
      include StreamListener

      def initialize(output)
        @xctx = Array.new
        @xhit = nil
        @xhsps = nil
        @xhsp = nil
        @out = output
      end
  
      def tag_start(name, attributes)
        if name == "Hit"
          @xhit = Hash.new
          @xhsps = Array.new
        elsif name == "Hsp"
          @xhsp = Hash.new
        end
        @xctx.push name
      end
  
      def text(text)
        if @xctx.last =~  /^Hit_(.*)$/
          @xhit[$1] = text      
        elsif @xctx.last =~ /^Hsp_(.*)$/
          @xhsp[$1] = text
        end
      end

      def tag_end(name)
        @xctx.pop
        if name == "Hit"
          show_hit(@xhit, @xhsps)
          @xhit = nil
          @xhsps = nil
        elsif name == "Hsp"
          @xhsps << @xhsp
          @xhsp = nil
        end
      end
  
      def show_hit(xhit, xhsps)
        @out.context "hit" do |hit|
          if !(index = xhit['id'].split('|').index('gi')).nil?
            hit.property 'identifier', xhit['id'].split('|').fetch(index+1, '')
            hit.property 'database', 'sequences'
          else
            hit.property 'identifier', xhit['accession']
          end
          
    	    extraIdRegexp = Regexp.new("^\\(?#{Regexp.escape(xhit['accession'])}(\\.\\d+)?\\)? *")
    	    hit.property 'description', xhit['def'].gsub(extraIdRegexp, '')
    	    hit.property 'length', xhit['len']
	    
    	    hit.spacer
          xhsps.each do |xhsp| hit.context "hsp" do |hsp|
            hsp.property 'hseq', xhsp['hseq']
            hsp.property 'qseq', xhsp['qseq']
        
            if xhsp['hit-frame'].to_i < 0
              hsp.property 'hloc', "complement("+xhsp['hit-from']+".."+xhsp['hit-to']+")"
            else
              hsp.property 'hloc', xhsp['hit-from']+".."+xhsp['hit-to']
            end
        
            if xhsp['query-frame'].to_i < 0
              hsp.property 'qloc', "complement("+xhsp['query-from']+".."+xhsp['query-to']+")"
            else
              hsp.property 'qloc', xhsp['query-from']+".."+xhsp['query-to']
            end
        
            hsp.property 'positive', xhsp['positive']
            hsp.property 'identity', xhsp['identity']
            hsp.property 'length', xhsp['align-len']
            hsp.property 'rscore', xhsp['score']
            hsp.property 'bscore', xhsp['bit-score']
            hsp.property 'evalue', xhsp['evalue']
          end; end
        end
      end
      
    end # NCB
  end # Reporter
end # DatabaseClient