#!/usr/bin/env ruby
#
# service.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-05.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

# Main module and base class for database service providers. 

require 'command'

module DatabaseClient
  module Service   

    ## Database service registration.

    @@services = []
    
    def self.register(service)
      @@services << service
    end
    def self.all
      @@services
    end
    def self.filter(identifier)
      @@services.select do |service|
        service.identified_by? identifier
      end
    end
    
    ## Database service base class.

    class Base
      attr_reader :identifier, :name
      
      def initialize(identifier, name)
        @commands = []
        @identifier = identifier
        @name = name
      end
      
      ## Command registration
      
      def register_command(command)
        @commands << command
      end
      def all_commands
        @commands
      end
      def filter_commands(identifier)
        @commands.select do |command|
          command.identified_by? identifier
        end
      end
      
      ## Misc

      def identified_by?(string)
        self.identifier.index(string) == 0
      end
      
    end # Base
    
  end # Service
end # DatabaseClient
