#!/usr/bin/env ruby
#
# spartan.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-22.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

# Spartan markup generator.

class Spartan
  attr_reader :context_stack, :output
  
  def initialize(output = $>)
    @context_stack = []
    @output = output
    yield self if block_given?
  end
  
  def indent
    context_stack.length + 1
  end
  
  def spacer
    output.puts
  end
  
  def property(key,value)
    output.puts ':' + ' '*indent + key.to_s + ' ' + value.to_s
  end
  
  def properties(hash)
    hash.each_pair { |key, value| property(key, value) }
  end
  
  def enter_context(name)
    output.puts '!' + ' '*indent + name.to_s
    context_stack.push name
  end
  
  def leave_context
    context_stack.pop
    output.puts ";"
    output.flush
  end
  
  def context(name, &block)
    enter_context(name)
    yield self if block_given?
    leave_context
  end
  
  def method_missing(meth,*args)
    property(meth.id2name, args.shift)
  end
end
