require 'ws/ebi/fetch_types.rb'
require 'soap/mapping'

module DatabaseClient::SOAP::EBI::Fetch

module Mapping
  EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
  LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
  NsExceptions = "http://exceptions.jdbfetch.ebi.ac.uk"
  NsWSDbfetch = "http://www.ebi.ac.uk/ws/services/WSDbfetch"

  EncodedRegistry.set(
    DatabaseClient::SOAP::EBI::Fetch::StringArray,
    ::SOAP::SOAPArray,
    ::SOAP::Mapping::EncodedRegistry::TypedArrayFactory,
    { :type => XSD::QName.new("http://www.w3.org/2001/XMLSchema", "string") }
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::InputException,
    :schema_type => XSD::QName.new(NsWSDbfetch, "InputException"),
    :schema_element => []
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::Exception,
    :schema_type => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::ParameterException,
    :schema_type => XSD::QName.new(NsExceptions, "DbfParamsException"),
    :schema_basetype => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::ConnectionException,
    :schema_type => XSD::QName.new(NsExceptions, "DbfConnException"),
    :schema_basetype => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::NoEntryFoundException,
    :schema_type => XSD::QName.new(NsExceptions, "DbfNoEntryFoundException"),
    :schema_basetype => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::InputException,
    :schema_type => XSD::QName.new(NsWSDbfetch, "InputException"),
    :schema_element => []
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::Exception,
    :schema_type => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::ParameterException,
    :schema_type => XSD::QName.new(NsExceptions, "DbfParamsException"),
    :schema_basetype => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::ConnectionException,
    :schema_type => XSD::QName.new(NsExceptions, "DbfConnException"),
    :schema_basetype => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Fetch::NoEntryFoundException,
    :schema_type => XSD::QName.new(NsExceptions, "DbfNoEntryFoundException"),
    :schema_basetype => XSD::QName.new(NsExceptions, "DbfException"),
    :schema_element => []
  )
end

end
