require 'ws/ebi/search_mapping.rb'
require 'soap/rpc/driver'

module DatabaseClient::SOAP::EBI::Search

class Driver < ::SOAP::RPC::Driver
  DefaultEndpointUrl = "http://www.ebi.ac.uk/ebisearch/service.ebi"

  Methods = [
    [ "urn:ListFields",
      "listFields",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "listFields"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "listFieldsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:ListAdditionalReferenceFields",
      "listAdditionalReferenceFields",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "listAdditionalReferenceFields"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "listAdditionalReferenceFieldsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetDomainsReferencedInEntry",
      "getDomainsReferencedInEntry",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getDomainsReferencedInEntry"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getDomainsReferencedInEntryResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetDomainsReferencedInDomain",
      "getDomainsReferencedInDomain",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getDomainsReferencedInDomain"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getDomainsReferencedInDomainResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetEntriesFieldUrls",
      "getEntriesFieldUrls",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntriesFieldUrls"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntriesFieldUrlsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetReferencedEntriesFlatSet",
      "getReferencedEntriesFlatSet",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getReferencedEntriesFlatSet"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getReferencedEntriesFlatSetResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetResults",
      "getResults",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getResults"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getResultsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetEntries",
      "getEntries",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntries"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntriesResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetEntryFieldUrls",
      "getEntryFieldUrls",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntryFieldUrls"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntryFieldUrlsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetEntry",
      "getEntry",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntry"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getEntryResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetNumberOfResults",
      "getNumberOfResults",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getNumberOfResults"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getNumberOfResultsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetResultsIds",
      "getResultsIds",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getResultsIds"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getResultsIdsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:ListDomains",
      "listDomains",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "listDomains"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "listDomainsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetReferencedEntriesSet",
      "getReferencedEntriesSet",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getReferencedEntriesSet"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getReferencedEntriesSetResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetReferencedEntries",
      "getReferencedEntries",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getReferencedEntries"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getReferencedEntriesResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "urn:GetAllResultsIds",
      "getAllResultsIds",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getAllResultsIds"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://www.ebi.ac.uk/EBISearchService", "getAllResultsIdsResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ]
  ]

  def initialize(endpoint_url = nil)
    endpoint_url ||= DefaultEndpointUrl
    super(endpoint_url, nil)
    self.mapping_registry = Mapping::EncodedRegistry
    self.literal_mapping_registry = Mapping::LiteralRegistry
    init_methods
  end

private

  def init_methods
    Methods.each do |definitions|
      opt = definitions.last
      if opt[:request_style] == :document
        add_document_operation(*definitions)
      else
        add_rpc_operation(*definitions)
        qname = definitions[0]
        name = definitions[2]
        if qname.name != name and qname.name.capitalize == name.capitalize
          ::SOAP::Mapping.define_singleton_method(self, qname.name) do |*arg|
            __send__(name, *arg)
          end
        end
      end
    end
  end
end

end
