require 'ws/ebi/search_types.rb'
require 'soap/mapping'

module DatabaseClient::SOAP::EBI::Search

module Mapping
  EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
  LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
  NsEBISearch = "http://www.ebi.ac.uk/EBISearchService"
  NsEbinocle = "http://webservice.ebinocle.ebi.ac.uk"

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::StringArray,
    :schema_type => XSD::QName.new(NsEBISearch, "ArrayOfString"),
    :schema_element => [
      ["string", "SOAP::SOAPString[]", [0, nil]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::StringArrayArray,
    :schema_type => XSD::QName.new(NsEBISearch, "ArrayOfArrayOfString"),
    :schema_element => [
      ["arrayOfString", ["DatabaseClient::SOAP::EBI::Search::StringArray[]", XSD::QName.new(NsEBISearch, "ArrayOfString")], [0, nil]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::EntryReferencesArray,
    :schema_type => XSD::QName.new(NsEbinocle, "ArrayOfEntryReferences"),
    :schema_element => [
      ["entryReferences", ["DatabaseClient::SOAP::EBI::Search::EntryReferences[]", XSD::QName.new(NsEbinocle, "EntryReferences")], [0, nil]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::EntryReferences,
    :schema_type => XSD::QName.new(NsEbinocle, "EntryReferences"),
    :schema_element => [
      ["entry", "SOAP::SOAPString", [0, 1]],
      ["references", "DatabaseClient::SOAP::EBI::Search::StringArrayArray", [0, 1]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::StringArray,
    :schema_type => XSD::QName.new(NsEBISearch, "ArrayOfString"),
    :schema_element => [
      ["string", "SOAP::SOAPString[]", [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::StringArrayArray,
    :schema_type => XSD::QName.new(NsEBISearch, "ArrayOfArrayOfString"),
    :schema_element => [
      ["arrayOfString", ["DatabaseClient::SOAP::EBI::Search::StringArray[]", XSD::QName.new(NsEBISearch, "ArrayOfString")], [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::EntryReferencesArray,
    :schema_type => XSD::QName.new(NsEbinocle, "ArrayOfEntryReferences"),
    :schema_element => [
      ["entryReferences", ["DatabaseClient::SOAP::EBI::Search::EntryReferences[]", XSD::QName.new(NsEbinocle, "EntryReferences")], [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::EntryReferences,
    :schema_type => XSD::QName.new(NsEbinocle, "EntryReferences"),
    :schema_element => [
      ["entry", "SOAP::SOAPString", [0, 1]],
      ["references", "DatabaseClient::SOAP::EBI::Search::StringArrayArray", [0, 1]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::ListFields,
    :schema_name => XSD::QName.new(NsEBISearch, "listFields"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::ListFieldsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "listFieldsResponse"),
    :schema_element => [
      ["arrayOfFieldNames", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::ListAdditionalReferenceFields,
    :schema_name => XSD::QName.new(NsEBISearch, "listAdditionalReferenceFields"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::ListAdditionalReferenceFieldsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "listAdditionalReferenceFieldsResponse"),
    :schema_element => [
      ["arrayOfFieldNames", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetDomainsReferencedInEntry,
    :schema_name => XSD::QName.new(NsEBISearch, "getDomainsReferencedInEntry"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entry", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetDomainsReferencedInEntryResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getDomainsReferencedInEntryResponse"),
    :schema_element => [
      ["arrayOfDomainNames", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetDomainsReferencedInDomain,
    :schema_name => XSD::QName.new(NsEBISearch, "getDomainsReferencedInDomain"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetDomainsReferencedInDomainResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getDomainsReferencedInDomainResponse"),
    :schema_element => [
      ["arrayOfDomainNames", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntriesFieldUrls,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntriesFieldUrls"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entries", "DatabaseClient::SOAP::EBI::Search::StringArray"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntriesFieldUrlsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntriesFieldUrlsResponse"),
    :schema_element => [
      ["arrayOfEntryUrlsValues", "DatabaseClient::SOAP::EBI::Search::StringArrayArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetReferencedEntriesFlatSet,
    :schema_name => XSD::QName.new(NsEBISearch, "getReferencedEntriesFlatSet"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entries", "DatabaseClient::SOAP::EBI::Search::StringArray"],
      ["referencedDomain", "SOAP::SOAPString"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetReferencedEntriesFlatSetResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getReferencedEntriesFlatSetResponse"),
    :schema_element => [
      ["arrayOfEntryValues", "DatabaseClient::SOAP::EBI::Search::StringArrayArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetResults,
    :schema_name => XSD::QName.new(NsEBISearch, "getResults"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["query", "SOAP::SOAPString"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"],
      ["start", "SOAP::SOAPInt"],
      ["size", "SOAP::SOAPInt"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetResultsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getResultsResponse"),
    :schema_element => [
      ["arrayOfEntryValues", "DatabaseClient::SOAP::EBI::Search::StringArrayArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntries,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntries"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entries", "DatabaseClient::SOAP::EBI::Search::StringArray"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntriesResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntriesResponse"),
    :schema_element => [
      ["arrayOfEntryValues", "DatabaseClient::SOAP::EBI::Search::StringArrayArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntryFieldUrls,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntryFieldUrls"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entry", "SOAP::SOAPString"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntryFieldUrlsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntryFieldUrlsResponse"),
    :schema_element => [
      ["entryUrlsValues", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntry,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntry"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entry", "SOAP::SOAPString"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetEntryResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getEntryResponse"),
    :schema_element => [
      ["entryValues", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetNumberOfResults,
    :schema_name => XSD::QName.new(NsEBISearch, "getNumberOfResults"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["query", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetNumberOfResultsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getNumberOfResultsResponse"),
    :schema_element => [
      ["numberOfResults", "SOAP::SOAPInt"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetResultsIds,
    :schema_name => XSD::QName.new(NsEBISearch, "getResultsIds"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["query", "SOAP::SOAPString"],
      ["start", "SOAP::SOAPInt"],
      ["size", "SOAP::SOAPInt"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetResultsIdsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getResultsIdsResponse"),
    :schema_element => [
      ["arrayOfIds", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::ListDomains,
    :schema_name => XSD::QName.new(NsEBISearch, "listDomains"),
    :schema_element => []
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::ListDomainsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "listDomainsResponse"),
    :schema_element => [
      ["arrayOfDomainNames", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetReferencedEntriesSet,
    :schema_name => XSD::QName.new(NsEBISearch, "getReferencedEntriesSet"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entries", "DatabaseClient::SOAP::EBI::Search::StringArray"],
      ["referencedDomain", "SOAP::SOAPString"],
      ["fields", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetReferencedEntriesSetResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getReferencedEntriesSetResponse"),
    :schema_element => [
      ["arrayOfEntryValues", "DatabaseClient::SOAP::EBI::Search::EntryReferencesArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetReferencedEntries,
    :schema_name => XSD::QName.new(NsEBISearch, "getReferencedEntries"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["entry", "SOAP::SOAPString"],
      ["referencedDomain", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetReferencedEntriesResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getReferencedEntriesResponse"),
    :schema_element => [
      ["arrayOfEntryIds", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetAllResultsIds,
    :schema_name => XSD::QName.new(NsEBISearch, "getAllResultsIds"),
    :schema_element => [
      ["domain", "SOAP::SOAPString"],
      ["query", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::Search::GetAllResultsIdsResponse,
    :schema_name => XSD::QName.new(NsEBISearch, "getAllResultsIdsResponse"),
    :schema_element => [
      ["arrayOfIds", "DatabaseClient::SOAP::EBI::Search::StringArray"]
    ]
  )
end

end
