require 'ws/ebi/search_main'
require 'xsd/qname'

module DatabaseClient::SOAP::EBI::Search

# {http://www.ebi.ac.uk/EBISearchService}ArrayOfString
class StringArray < ::Array
end

# {http://www.ebi.ac.uk/EBISearchService}ArrayOfArrayOfString
class StringArrayArray < ::Array
end

# {http://webservice.ebinocle.ebi.ac.uk}ArrayOfEntryReferences
class EntryReferencesArray < ::Array
end

# {http://webservice.ebinocle.ebi.ac.uk}EntryReferences
#   entry - SOAP::SOAPString
#   references - DatabaseClient::SOAP::EBI::Search::StringArrayArray
class EntryReferences
  attr_accessor :entry
  attr_accessor :references

  def initialize(entry = nil, references = nil)
    @entry = entry
    @references = references
  end
end

# {http://www.ebi.ac.uk/EBISearchService}listFields
#   domain - SOAP::SOAPString
class ListFields
  attr_accessor :domain

  def initialize(domain = nil)
    @domain = domain
  end
end

# {http://www.ebi.ac.uk/EBISearchService}listFieldsResponse
#   arrayOfFieldNames - DatabaseClient::SOAP::EBI::Search::StringArray
class ListFieldsResponse
  attr_accessor :arrayOfFieldNames

  def initialize(arrayOfFieldNames = nil)
    @arrayOfFieldNames = arrayOfFieldNames
  end
end

# {http://www.ebi.ac.uk/EBISearchService}listAdditionalReferenceFields
#   domain - SOAP::SOAPString
class ListAdditionalReferenceFields
  attr_accessor :domain

  def initialize(domain = nil)
    @domain = domain
  end
end

# {http://www.ebi.ac.uk/EBISearchService}listAdditionalReferenceFieldsResponse
#   arrayOfFieldNames - DatabaseClient::SOAP::EBI::Search::StringArray
class ListAdditionalReferenceFieldsResponse
  attr_accessor :arrayOfFieldNames

  def initialize(arrayOfFieldNames = nil)
    @arrayOfFieldNames = arrayOfFieldNames
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getDomainsReferencedInEntry
#   domain - SOAP::SOAPString
#   entry - SOAP::SOAPString
class GetDomainsReferencedInEntry
  attr_accessor :domain
  attr_accessor :entry

  def initialize(domain = nil, entry = nil)
    @domain = domain
    @entry = entry
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getDomainsReferencedInEntryResponse
#   arrayOfDomainNames - DatabaseClient::SOAP::EBI::Search::StringArray
class GetDomainsReferencedInEntryResponse
  attr_accessor :arrayOfDomainNames

  def initialize(arrayOfDomainNames = nil)
    @arrayOfDomainNames = arrayOfDomainNames
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getDomainsReferencedInDomain
#   domain - SOAP::SOAPString
class GetDomainsReferencedInDomain
  attr_accessor :domain

  def initialize(domain = nil)
    @domain = domain
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getDomainsReferencedInDomainResponse
#   arrayOfDomainNames - DatabaseClient::SOAP::EBI::Search::StringArray
class GetDomainsReferencedInDomainResponse
  attr_accessor :arrayOfDomainNames

  def initialize(arrayOfDomainNames = nil)
    @arrayOfDomainNames = arrayOfDomainNames
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntriesFieldUrls
#   domain - SOAP::SOAPString
#   entries - DatabaseClient::SOAP::EBI::Search::StringArray
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
class GetEntriesFieldUrls
  attr_accessor :domain
  attr_accessor :entries
  attr_accessor :fields

  def initialize(domain = nil, entries = nil, fields = nil)
    @domain = domain
    @entries = entries
    @fields = fields
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntriesFieldUrlsResponse
#   arrayOfEntryUrlsValues - DatabaseClient::SOAP::EBI::Search::StringArrayArray
class GetEntriesFieldUrlsResponse
  attr_accessor :arrayOfEntryUrlsValues

  def initialize(arrayOfEntryUrlsValues = nil)
    @arrayOfEntryUrlsValues = arrayOfEntryUrlsValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getReferencedEntriesFlatSet
#   domain - SOAP::SOAPString
#   entries - DatabaseClient::SOAP::EBI::Search::StringArray
#   referencedDomain - SOAP::SOAPString
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
class GetReferencedEntriesFlatSet
  attr_accessor :domain
  attr_accessor :entries
  attr_accessor :referencedDomain
  attr_accessor :fields

  def initialize(domain = nil, entries = nil, referencedDomain = nil, fields = nil)
    @domain = domain
    @entries = entries
    @referencedDomain = referencedDomain
    @fields = fields
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getReferencedEntriesFlatSetResponse
#   arrayOfEntryValues - DatabaseClient::SOAP::EBI::Search::StringArrayArray
class GetReferencedEntriesFlatSetResponse
  attr_accessor :arrayOfEntryValues

  def initialize(arrayOfEntryValues = nil)
    @arrayOfEntryValues = arrayOfEntryValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getResults
#   domain - SOAP::SOAPString
#   query - SOAP::SOAPString
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
#   start - SOAP::SOAPInt
#   size - SOAP::SOAPInt
class GetResults
  attr_accessor :domain
  attr_accessor :query
  attr_accessor :fields
  attr_accessor :start
  attr_accessor :size

  def initialize(domain = nil, query = nil, fields = nil, start = nil, size = nil)
    @domain = domain
    @query = query
    @fields = fields
    @start = start
    @size = size
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getResultsResponse
#   arrayOfEntryValues - DatabaseClient::SOAP::EBI::Search::StringArrayArray
class GetResultsResponse
  attr_accessor :arrayOfEntryValues

  def initialize(arrayOfEntryValues = nil)
    @arrayOfEntryValues = arrayOfEntryValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntries
#   domain - SOAP::SOAPString
#   entries - DatabaseClient::SOAP::EBI::Search::StringArray
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
class GetEntries
  attr_accessor :domain
  attr_accessor :entries
  attr_accessor :fields

  def initialize(domain = nil, entries = nil, fields = nil)
    @domain = domain
    @entries = entries
    @fields = fields
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntriesResponse
#   arrayOfEntryValues - DatabaseClient::SOAP::EBI::Search::StringArrayArray
class GetEntriesResponse
  attr_accessor :arrayOfEntryValues

  def initialize(arrayOfEntryValues = nil)
    @arrayOfEntryValues = arrayOfEntryValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntryFieldUrls
#   domain - SOAP::SOAPString
#   entry - SOAP::SOAPString
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
class GetEntryFieldUrls
  attr_accessor :domain
  attr_accessor :entry
  attr_accessor :fields

  def initialize(domain = nil, entry = nil, fields = nil)
    @domain = domain
    @entry = entry
    @fields = fields
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntryFieldUrlsResponse
#   entryUrlsValues - DatabaseClient::SOAP::EBI::Search::StringArray
class GetEntryFieldUrlsResponse
  attr_accessor :entryUrlsValues

  def initialize(entryUrlsValues = nil)
    @entryUrlsValues = entryUrlsValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntry
#   domain - SOAP::SOAPString
#   entry - SOAP::SOAPString
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
class GetEntry
  attr_accessor :domain
  attr_accessor :entry
  attr_accessor :fields

  def initialize(domain = nil, entry = nil, fields = nil)
    @domain = domain
    @entry = entry
    @fields = fields
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getEntryResponse
#   entryValues - DatabaseClient::SOAP::EBI::Search::StringArray
class GetEntryResponse
  attr_accessor :entryValues

  def initialize(entryValues = nil)
    @entryValues = entryValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getNumberOfResults
#   domain - SOAP::SOAPString
#   query - SOAP::SOAPString
class GetNumberOfResults
  attr_accessor :domain
  attr_accessor :query

  def initialize(domain = nil, query = nil)
    @domain = domain
    @query = query
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getNumberOfResultsResponse
#   numberOfResults - SOAP::SOAPInt
class GetNumberOfResultsResponse
  attr_accessor :numberOfResults

  def initialize(numberOfResults = nil)
    @numberOfResults = numberOfResults
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getResultsIds
#   domain - SOAP::SOAPString
#   query - SOAP::SOAPString
#   start - SOAP::SOAPInt
#   size - SOAP::SOAPInt
class GetResultsIds
  attr_accessor :domain
  attr_accessor :query
  attr_accessor :start
  attr_accessor :size

  def initialize(domain = nil, query = nil, start = nil, size = nil)
    @domain = domain
    @query = query
    @start = start
    @size = size
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getResultsIdsResponse
#   arrayOfIds - DatabaseClient::SOAP::EBI::Search::StringArray
class GetResultsIdsResponse
  attr_accessor :arrayOfIds

  def initialize(arrayOfIds = nil)
    @arrayOfIds = arrayOfIds
  end
end

# {http://www.ebi.ac.uk/EBISearchService}listDomains
class ListDomains
  def initialize
  end
end

# {http://www.ebi.ac.uk/EBISearchService}listDomainsResponse
#   arrayOfDomainNames - DatabaseClient::SOAP::EBI::Search::StringArray
class ListDomainsResponse
  attr_accessor :arrayOfDomainNames

  def initialize(arrayOfDomainNames = nil)
    @arrayOfDomainNames = arrayOfDomainNames
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getReferencedEntriesSet
#   domain - SOAP::SOAPString
#   entries - DatabaseClient::SOAP::EBI::Search::StringArray
#   referencedDomain - SOAP::SOAPString
#   fields - DatabaseClient::SOAP::EBI::Search::StringArray
class GetReferencedEntriesSet
  attr_accessor :domain
  attr_accessor :entries
  attr_accessor :referencedDomain
  attr_accessor :fields

  def initialize(domain = nil, entries = nil, referencedDomain = nil, fields = nil)
    @domain = domain
    @entries = entries
    @referencedDomain = referencedDomain
    @fields = fields
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getReferencedEntriesSetResponse
#   arrayOfEntryValues - DatabaseClient::SOAP::EBI::Search::EntryReferencesArray
class GetReferencedEntriesSetResponse
  attr_accessor :arrayOfEntryValues

  def initialize(arrayOfEntryValues = nil)
    @arrayOfEntryValues = arrayOfEntryValues
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getReferencedEntries
#   domain - SOAP::SOAPString
#   entry - SOAP::SOAPString
#   referencedDomain - SOAP::SOAPString
class GetReferencedEntries
  attr_accessor :domain
  attr_accessor :entry
  attr_accessor :referencedDomain

  def initialize(domain = nil, entry = nil, referencedDomain = nil)
    @domain = domain
    @entry = entry
    @referencedDomain = referencedDomain
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getReferencedEntriesResponse
#   arrayOfEntryIds - DatabaseClient::SOAP::EBI::Search::StringArray
class GetReferencedEntriesResponse
  attr_accessor :arrayOfEntryIds

  def initialize(arrayOfEntryIds = nil)
    @arrayOfEntryIds = arrayOfEntryIds
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getAllResultsIds
#   domain - SOAP::SOAPString
#   query - SOAP::SOAPString
class GetAllResultsIds
  attr_accessor :domain
  attr_accessor :query

  def initialize(domain = nil, query = nil)
    @domain = domain
    @query = query
  end
end

# {http://www.ebi.ac.uk/EBISearchService}getAllResultsIdsResponse
#   arrayOfIds - DatabaseClient::SOAP::EBI::Search::StringArray
class GetAllResultsIdsResponse
  attr_accessor :arrayOfIds

  def initialize(arrayOfIds = nil)
    @arrayOfIds = arrayOfIds
  end
end

end
