#!/usr/bin/env ruby
#
# wublast_driver.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/ebi/wublast_mapping'
require 'soap/rpc/driver'

module DatabaseClient::SOAP::EBI::WUBLAST

class Driver < ::SOAP::RPC::Driver
  DefaultEndpointUrl = "http://www.ebi.ac.uk/cgi-bin/webservices/WSWUBlast"
  NsWSWUBlast = "http://www.ebi.ac.uk/WSWUBlast"

  Methods = [
    [ XSD::QName.new(NsWSWUBlast, "runWUBlast"),
      "http://www.ebi.ac.uk/WSWUBlast#runWUBlast",
      "runWUBlast",
      [ ["in", "params", ["DatabaseClient::SOAP::EBI::WUBLAST::InputParams", "http://www.ebi.ac.uk/WSWUBlast", "inputParams"]],
        ["in", "content", ["DatabaseClient::SOAP::EBI::WUBLAST::WSArrayofData", "http://www.ebi.ac.uk/WSWUBlast", "WSArrayofData"]],
        ["retval", "jobid", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "poll"),
      "http://www.ebi.ac.uk/WSWUBlast#poll",
      "poll",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["in", "type", ["::SOAP::SOAPString"]],
        ["retval", "result", ["::SOAP::SOAPBase64"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "getIds"),
      "http://www.ebi.ac.uk/WSWUBlast#getIds",
      "getIds",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["retval", "result", ["DatabaseClient::SOAP::EBI::WUBLAST::ArrayOf_xsd_string", "http://www.ebi.ac.uk/WSWUBlast", "ArrayOf_xsd_string"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "checkStatus"),
      "http://www.ebi.ac.uk/WSWUBlast#checkStatus",
      "checkStatus",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["retval", "status", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "getResults"),
      "http://www.ebi.ac.uk/WSWUBlast#getResults",
      "getResults",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["retval", "results", ["DatabaseClient::SOAP::EBI::WUBLAST::WSArrayofFile", "http://www.ebi.ac.uk/WSWUBlast", "WSArrayofFile"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "getOutput"),
      "http://www.ebi.ac.uk/WSWUBlast#getOutput",
      "getOutput",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["retval", "result", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "getXML"),
      "http://www.ebi.ac.uk/WSWUBlast#getXML",
      "getXML",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["retval", "result", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "blastp"),
      "http://www.ebi.ac.uk/WSWUBlast#blastp",
      "blastp",
      [ ["in", "database", ["::SOAP::SOAPString"]],
        ["in", "sequence", ["::SOAP::SOAPString"]],
        ["in", "email", ["::SOAP::SOAPString"]],
        ["retval", "jobid", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "blastn"),
      "http://www.ebi.ac.uk/WSWUBlast#blastn",
      "blastn",
      [ ["in", "database", ["::SOAP::SOAPString"]],
        ["in", "sequence", ["::SOAP::SOAPString"]],
        ["in", "email", ["::SOAP::SOAPString"]],
        ["retval", "jobid", ["::SOAP::SOAPString"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "polljob"),
      "http://www.ebi.ac.uk/WSWUBlast#polljob",
      "polljob",
      [ ["in", "jobid", ["::SOAP::SOAPString"]],
        ["in", "outformat", ["::SOAP::SOAPString"]],
        ["retval", "result", ["::SOAP::SOAPBase64"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ],
    [ XSD::QName.new(NsWSWUBlast, "doWUBlast"),
      "http://www.ebi.ac.uk/WSWUBlast#doWUBlast",
      "doWUBlast",
      [ ["in", "params", ["DatabaseClient::SOAP::EBI::WUBLAST::InputParams", "http://www.ebi.ac.uk/WSWUBlast", "inputParams"]],
        ["in", "content", ["::SOAP::SOAPBase64"]],
        ["retval", "result", ["::SOAP::SOAPBase64"]] ],
      { :request_style =>  :rpc, :request_use =>  :encoded,
        :response_style => :rpc, :response_use => :encoded,
        :faults => {} }
    ]
  ]

  def initialize(endpoint_url = nil)
    endpoint_url ||= DefaultEndpointUrl
    super(endpoint_url, nil)
    self.mapping_registry = Mapping::EncodedRegistry
    self.literal_mapping_registry = Mapping::LiteralRegistry
    init_methods
  end

private

  def init_methods
    Methods.each do |definitions|
      opt = definitions.last
      if opt[:request_style] == :document
        add_document_operation(*definitions)
      else
        add_rpc_operation(*definitions)
        qname = definitions[0]
        name = definitions[2]
        if qname.name != name and qname.name.capitalize == name.capitalize
          ::SOAP::Mapping.define_singleton_method(self, qname.name) do |*arg|
            __send__(name, *arg)
          end
        end
      end
    end
  end
end


end
