#!/usr/bin/env ruby
#
# wublast_mapping.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/ebi/wublast_types'
require 'soap/mapping'

module DatabaseClient::SOAP::EBI::WUBLAST

module Mapping
  EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
  LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
  NsWSWUBlast = "http://www.ebi.ac.uk/WSWUBlast"

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::WUBLAST::Parameters,
    :schema_type => XSD::QName.new(NsWSWUBlast, "inputParams"),
    :schema_element => [
      ["program", ["SOAP::SOAPString", XSD::QName.new(nil, "program")]],
      ["database", ["SOAP::SOAPString", XSD::QName.new(nil, "database")]],
      ["matrix", ["SOAP::SOAPString", XSD::QName.new(nil, "matrix")]],
      ["exp", ["SOAP::SOAPFloat", XSD::QName.new(nil, "exp")]],
      ["echofilter", ["SOAP::SOAPBoolean", XSD::QName.new(nil, "echofilter")]],
      ["filter", ["SOAP::SOAPString", XSD::QName.new(nil, "filter")]],
      ["numal", ["SOAP::SOAPInt", XSD::QName.new(nil, "numal")]],
      ["scores", ["SOAP::SOAPInt", XSD::QName.new(nil, "scores")]],
      ["sensitivity", ["SOAP::SOAPString", XSD::QName.new(nil, "sensitivity")]],
      ["sort", ["SOAP::SOAPString", XSD::QName.new(nil, "sort")]],
      ["stats", ["SOAP::SOAPString", XSD::QName.new(nil, "stats")]],
      ["strand", ["SOAP::SOAPString", XSD::QName.new(nil, "strand")]],
      ["outformat", ["SOAP::SOAPString", XSD::QName.new(nil, "outformat")]],
      ["topcombon", ["SOAP::SOAPInt", XSD::QName.new(nil, "topcombon")]],
      ["async", ["SOAP::SOAPBoolean", XSD::QName.new(nil, "async")]],
      ["email", ["SOAP::SOAPString", XSD::QName.new(nil, "email")]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::WUBLAST::Data,
    :schema_type => XSD::QName.new(NsWSWUBlast, "data"),
    :schema_element => [
      ["type", ["SOAP::SOAPString", XSD::QName.new(nil, "type")]],
      ["content", ["SOAP::SOAPString", XSD::QName.new(nil, "content")]]
    ]
  )

  EncodedRegistry.set(
    DatabaseClient::SOAP::EBI::WUBLAST::StringArray,
    ::SOAP::SOAPArray,
    ::SOAP::Mapping::EncodedRegistry::TypedArrayFactory,
    { :type => XSD::QName.new("http://www.w3.org/2001/XMLSchema", "string") }
  )

  EncodedRegistry.set(
    DatabaseClient::SOAP::EBI::WUBLAST::FileArray,
    ::SOAP::SOAPArray,
    ::SOAP::Mapping::EncodedRegistry::TypedArrayFactory,
    { :type => XSD::QName.new(NsWSWUBlast, "WSFile") }
  )

  EncodedRegistry.set(
    DatabaseClient::SOAP::EBI::WUBLAST::DataArray,
    ::SOAP::SOAPArray,
    ::SOAP::Mapping::EncodedRegistry::TypedArrayFactory,
    { :type => XSD::QName.new(NsWSWUBlast, "data") }
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::EBI::WUBLAST::File,
    :schema_type => XSD::QName.new(NsWSWUBlast, "WSFile"),
    :schema_element => [
      ["type", ["SOAP::SOAPString", XSD::QName.new(nil, "type")]],
      ["ext", ["SOAP::SOAPString", XSD::QName.new(nil, "ext")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::WUBLAST::Parameters,
    :schema_type => XSD::QName.new(NsWSWUBlast, "inputParams"),
    :schema_element => [
      ["program", ["SOAP::SOAPString", XSD::QName.new(nil, "program")]],
      ["database", ["SOAP::SOAPString", XSD::QName.new(nil, "database")]],
      ["matrix", ["SOAP::SOAPString", XSD::QName.new(nil, "matrix")]],
      ["exp", ["SOAP::SOAPFloat", XSD::QName.new(nil, "exp")]],
      ["echofilter", ["SOAP::SOAPBoolean", XSD::QName.new(nil, "echofilter")]],
      ["filter", ["SOAP::SOAPString", XSD::QName.new(nil, "filter")]],
      ["numal", ["SOAP::SOAPInt", XSD::QName.new(nil, "numal")]],
      ["scores", ["SOAP::SOAPInt", XSD::QName.new(nil, "scores")]],
      ["sensitivity", ["SOAP::SOAPString", XSD::QName.new(nil, "sensitivity")]],
      ["sort", ["SOAP::SOAPString", XSD::QName.new(nil, "sort")]],
      ["stats", ["SOAP::SOAPString", XSD::QName.new(nil, "stats")]],
      ["strand", ["SOAP::SOAPString", XSD::QName.new(nil, "strand")]],
      ["outformat", ["SOAP::SOAPString", XSD::QName.new(nil, "outformat")]],
      ["topcombon", ["SOAP::SOAPInt", XSD::QName.new(nil, "topcombon")]],
      ["async", ["SOAP::SOAPBoolean", XSD::QName.new(nil, "async")]],
      ["email", ["SOAP::SOAPString", XSD::QName.new(nil, "email")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::WUBLAST::Data,
    :schema_type => XSD::QName.new(NsWSWUBlast, "data"),
    :schema_element => [
      ["type", ["SOAP::SOAPString", XSD::QName.new(nil, "type")]],
      ["content", ["SOAP::SOAPString", XSD::QName.new(nil, "content")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::EBI::WUBLAST::File,
    :schema_type => XSD::QName.new(NsWSWUBlast, "WSFile"),
    :schema_element => [
      ["type", ["SOAP::SOAPString", XSD::QName.new(nil, "type")]],
      ["ext", ["SOAP::SOAPString", XSD::QName.new(nil, "ext")]]
    ]
  )
end

end
