#!/usr/bin/env ruby
#
# wublast_types.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/ebi/wublast_main'
require 'xsd/qname'

module DatabaseClient::SOAP::EBI::WUBLAST

# {http://www.ebi.ac.uk/WSWUBlast}inputParams
#   program - SOAP::SOAPString
#   database - SOAP::SOAPString
#   matrix - SOAP::SOAPString
#   exp - SOAP::SOAPFloat
#   echofilter - SOAP::SOAPBoolean
#   filter - SOAP::SOAPString
#   numal - SOAP::SOAPInt
#   scores - SOAP::SOAPInt
#   sensitivity - SOAP::SOAPString
#   sort - SOAP::SOAPString
#   stats - SOAP::SOAPString
#   strand - SOAP::SOAPString
#   outformat - SOAP::SOAPString
#   topcombon - SOAP::SOAPInt
#   async - SOAP::SOAPBoolean
#   email - SOAP::SOAPString
class Parameters
  attr_accessor :program
  attr_accessor :database
  attr_accessor :matrix
  attr_accessor :exp
  attr_accessor :echofilter
  attr_accessor :filter
  attr_accessor :numal
  attr_accessor :scores
  attr_accessor :sensitivity
  attr_accessor :sort
  attr_accessor :stats
  attr_accessor :strand
  attr_accessor :outformat
  attr_accessor :topcombon
  attr_accessor :async
  attr_accessor :email

  def initialize(program = nil, database = nil, matrix = nil, exp = nil, echofilter = nil, filter = nil, numal = nil, scores = nil, sensitivity = nil, sort = nil, stats = nil, strand = nil, outformat = nil, topcombon = nil, async = nil, email = nil)
    @program = program
    @database = database
    @matrix = matrix
    @exp = exp
    @echofilter = echofilter
    @filter = filter
    @numal = numal
    @scores = scores
    @sensitivity = sensitivity
    @sort = sort
    @stats = stats
    @strand = strand
    @outformat = outformat
    @topcombon = topcombon
    @async = async
    @email = email
  end
end

# {http://www.ebi.ac.uk/WSWUBlast}data
#   type - SOAP::SOAPString
#   content - SOAP::SOAPString
class Data
  attr_accessor :type
  attr_accessor :content

  def initialize(type = nil, content = nil)
    @type = type
    @content = content
  end
end

# {http://www.ebi.ac.uk/WSWUBlast}WSFile
#   type - SOAP::SOAPString
#   ext - SOAP::SOAPString
class File
  attr_accessor :type
  attr_accessor :ext

  def initialize(type = nil, ext = nil)
    @type = type
    @ext = ext
  end
end

# {http://www.ebi.ac.uk/WSWUBlast}ArrayOf_xsd_string
class StringArray < ::Array
end

# {http://www.ebi.ac.uk/WSWUBlast}WSArrayofFile
class FileArray < ::Array
end

# {http://www.ebi.ac.uk/WSWUBlast}WSArrayofData
class DataArray < ::Array
end

end
