#!/usr/bin/env ruby
#
# regular_driver.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/mrs/regular_mapping'
require 'soap/rpc/driver'

module DatabaseClient::SOAP::MRS::Regular

class Driver < ::SOAP::RPC::Driver
  DefaultEndpointUrl = "http://mrs.cmbi.ru.nl/mrsws"

  Methods = [
    [ "",
      "getDatabankInfo",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "GetDatabankInfo"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "GetDatabankInfoResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "getEntry",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "GetEntry"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "GetEntryResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "getIndices",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "GetIndices"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "GetIndicesResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "find",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "Find"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "findSimilar",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindSimilar"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "findAll",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindAll"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindAllResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "findAllSimilar",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindAllSimilar"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "FindAllSimilarResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "count",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "Count"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "CountResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "cooccurrence",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "Cooccurrence"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "CooccurrenceResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "spellCheck",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "SpellCheck"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws", "SpellCheckResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ]
  ]

  def initialize(endpoint_url = nil)
    endpoint_url ||= DefaultEndpointUrl
    super(endpoint_url, nil)
    self.mapping_registry = Mapping::EncodedRegistry
    self.literal_mapping_registry = Mapping::LiteralRegistry
    init_methods
  end

private

  def init_methods
    Methods.each do |definitions|
      opt = definitions.last
      if opt[:request_style] == :document
        add_document_operation(*definitions)
      else
        add_rpc_operation(*definitions)
        qname = definitions[0]
        name = definitions[2]
        if qname.name != name and qname.name.capitalize == name.capitalize
          ::SOAP::Mapping.define_singleton_method(self, qname.name) do |*arg|
            __send__(name, *arg)
          end
        end
      end
    end
  end
end

end
