#!/usr/bin/env ruby
#
# regular_mapping.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/mrs/regular_types'
require 'soap/mapping'

module DatabaseClient::SOAP::MRS::Regular

module Mapping
  EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
  LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
  NsMrsws = "http://mrs.cmbi.ru.nl/mrsws"

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::File,
    :schema_type => XSD::QName.new(NsMrsws, "FileInfo"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["uuid", "SOAP::SOAPString"],
      ["version", "SOAP::SOAPString"],
      ["path", "SOAP::SOAPString"],
      ["modification_date", ["SOAP::SOAPString", XSD::QName.new(NsMrsws, "modification-date")]],
      ["entries", "SOAP::SOAPUnsignedLong"],
      ["file_size", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrsws, "file-size")]],
      ["raw_data_size", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrsws, "raw-data-size")]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Databank,
    :schema_type => XSD::QName.new(NsMrsws, "DatabankInfo"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["name", "SOAP::SOAPString"],
      ["url", "SOAP::SOAPString"],
      ["script", "SOAP::SOAPString"],
      ["blastable", "SOAP::SOAPBoolean"],
      ["files", "DatabaseClient::SOAP::MRS::Regular::File[]", [0, nil]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Index,
    :schema_type => XSD::QName.new(NsMrsws, "Index"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["description", "SOAP::SOAPString"],
      ["count", "SOAP::SOAPUnsignedLong"],
      ["type", "DatabaseClient::SOAP::MRS::Regular::IndexType"]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Hit,
    :schema_type => XSD::QName.new(NsMrsws, "Hit"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["id", "SOAP::SOAPString"],
      ["title", "SOAP::SOAPString"],
      ["score", "SOAP::SOAPFloat"]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Hits,
    :schema_type => XSD::QName.new(NsMrsws, "FindAllResult"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["count", "SOAP::SOAPUnsignedLong"],
      ["hits", "DatabaseClient::SOAP::MRS::Regular::Hit[]", [0, nil]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Format,
    :schema_type => XSD::QName.new(NsMrsws, "Format")
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::IndexType,
    :schema_type => XSD::QName.new(NsMrsws, "IndexType")
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Algorithm,
    :schema_type => XSD::QName.new(NsMrsws, "Algorithm")
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::File,
    :schema_type => XSD::QName.new(NsMrsws, "FileInfo"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["uuid", "SOAP::SOAPString"],
      ["version", "SOAP::SOAPString"],
      ["path", "SOAP::SOAPString"],
      ["modification_date", ["SOAP::SOAPString", XSD::QName.new(NsMrsws, "modification-date")]],
      ["entries", "SOAP::SOAPUnsignedLong"],
      ["file_size", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrsws, "file-size")]],
      ["raw_data_size", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrsws, "raw-data-size")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Databank,
    :schema_type => XSD::QName.new(NsMrsws, "DatabankInfo"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["name", "SOAP::SOAPString"],
      ["url", "SOAP::SOAPString"],
      ["script", "SOAP::SOAPString"],
      ["blastable", "SOAP::SOAPBoolean"],
      ["files", "DatabaseClient::SOAP::MRS::Regular::File[]", [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Index,
    :schema_type => XSD::QName.new(NsMrsws, "Index"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["description", "SOAP::SOAPString"],
      ["count", "SOAP::SOAPUnsignedLong"],
      ["type", "DatabaseClient::SOAP::MRS::Regular::IndexType"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Hit,
    :schema_type => XSD::QName.new(NsMrsws, "Hit"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["id", "SOAP::SOAPString"],
      ["title", "SOAP::SOAPString"],
      ["score", "SOAP::SOAPFloat"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Hits,
    :schema_type => XSD::QName.new(NsMrsws, "FindAllResult"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["count", "SOAP::SOAPUnsignedLong"],
      ["hits", "DatabaseClient::SOAP::MRS::Regular::Hit[]", [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Format,
    :schema_type => XSD::QName.new(NsMrsws, "Format")
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::IndexType,
    :schema_type => XSD::QName.new(NsMrsws, "IndexType")
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::Algorithm,
    :schema_type => XSD::QName.new(NsMrsws, "Algorithm")
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::DatabankInfoParameters,
    :schema_name => XSD::QName.new(NsMrsws, "GetDatabankInfo"),
    :schema_element => [
      ["db", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::DatabankInfoResponse,
    :schema_name => XSD::QName.new(NsMrsws, "GetDatabankInfoResponse"),
    :schema_element => [
      ["info", "DatabaseClient::SOAP::MRS::Regular::Databank[]", [1, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::GetEntryParameters,
    :schema_name => XSD::QName.new(NsMrsws, "GetEntry"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["id", "SOAP::SOAPString"],
      ["format", "DatabaseClient::SOAP::MRS::Regular::Format"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::GetEntryResponse,
    :schema_name => XSD::QName.new(NsMrsws, "GetEntryResponse"),
    :schema_element => [
      ["entry", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::GetIndicesParameters,
    :schema_name => XSD::QName.new(NsMrsws, "GetIndices"),
    :schema_element => [
      ["db", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::GetIndicesResponse,
    :schema_name => XSD::QName.new(NsMrsws, "GetIndicesResponse"),
    :schema_element => [
      ["indices", "DatabaseClient::SOAP::MRS::Regular::Index[]", [1, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindParameters,
    :schema_name => XSD::QName.new(NsMrsws, "Find"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["queryterms", "SOAP::SOAPString[]", [1, nil]],
      ["algorithm", "DatabaseClient::SOAP::MRS::Regular::Algorithm"],
      ["alltermsrequired", "SOAP::SOAPBoolean"],
      ["booleanfilter", "SOAP::SOAPString"],
      ["resultoffset", "SOAP::SOAPInt"],
      ["maxresultcount", "SOAP::SOAPInt"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindResponse,
    :schema_name => XSD::QName.new(NsMrsws, "FindResponse"),
    :schema_element => [
      ["count", "SOAP::SOAPUnsignedLong"],
      ["hits", "DatabaseClient::SOAP::MRS::Regular::Hit[]", [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindSimilarParameters,
    :schema_name => XSD::QName.new(NsMrsws, "FindSimilar"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["id", "SOAP::SOAPString"],
      ["algorithm", "DatabaseClient::SOAP::MRS::Regular::Algorithm"],
      ["resultoffset", "SOAP::SOAPInt"],
      ["maxresultcount", "SOAP::SOAPInt"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindAllParameters,
    :schema_name => XSD::QName.new(NsMrsws, "FindAll"),
    :schema_element => [
      ["queryterms", "SOAP::SOAPString[]", [1, nil]],
      ["algorithm", "DatabaseClient::SOAP::MRS::Regular::Algorithm"],
      ["alltermsrequired", "SOAP::SOAPBoolean"],
      ["booleanfilter", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindAllResponse,
    :schema_name => XSD::QName.new(NsMrsws, "FindAllResponse"),
    :schema_element => [
      ["response", "DatabaseClient::SOAP::MRS::Regular::Hits[]", [1, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindAllSimilarParameters,
    :schema_name => XSD::QName.new(NsMrsws, "FindAllSimilar"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["id", "SOAP::SOAPString"],
      ["algorithm", "DatabaseClient::SOAP::MRS::Regular::Algorithm"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::FindAllSimilarResponse,
    :schema_name => XSD::QName.new(NsMrsws, "FindAllSimilarResponse"),
    :schema_element => [
      ["response", "DatabaseClient::SOAP::MRS::Regular::Hits[]", [1, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::CountParameters,
    :schema_name => XSD::QName.new(NsMrsws, "Count"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["booleanquery", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::CountResponse,
    :schema_name => XSD::QName.new(NsMrsws, "CountResponse"),
    :schema_element => [
      ["response", "SOAP::SOAPUnsignedLong"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::CooccurrenceParameters,
    :schema_name => XSD::QName.new(NsMrsws, "Cooccurrence"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["ids", "SOAP::SOAPString[]", [1, nil]],
      ["idf_cutoff", ["SOAP::SOAPFloat", XSD::QName.new(NsMrsws, "idf-cutoff")]],
      ["resultoffset", "SOAP::SOAPInt"],
      ["maxresultcount", "SOAP::SOAPInt"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::CooccurrenceResponse,
    :schema_name => XSD::QName.new(NsMrsws, "CooccurrenceResponse"),
    :schema_element => [
      ["terms", "SOAP::SOAPString[]", [1, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::SpellCheckParameters,
    :schema_name => XSD::QName.new(NsMrsws, "SpellCheck"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["queryterm", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::Regular::SpellCheckResponse,
    :schema_name => XSD::QName.new(NsMrsws, "SpellCheckResponse"),
    :schema_element => [
      ["suggestions", "SOAP::SOAPString[]", [1, nil]]
    ]
  )
end

end
