#!/usr/bin/env ruby
#
# regular_types.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/mrs/regular_main'
require 'xsd/qname'

module DatabaseClient::SOAP::MRS::Regular

# {http://mrs.cmbi.ru.nl/mrsws}FileInfo
#   id - SOAP::SOAPString
#   uuid - SOAP::SOAPString
#   version - SOAP::SOAPString
#   path - SOAP::SOAPString
#   modification_date - SOAP::SOAPString
#   entries - SOAP::SOAPUnsignedLong
#   file_size - SOAP::SOAPUnsignedLong
#   raw_data_size - SOAP::SOAPUnsignedLong
class File
  attr_accessor :id
  attr_accessor :uuid
  attr_accessor :version
  attr_accessor :path
  attr_accessor :modification_date
  attr_accessor :entries
  attr_accessor :file_size
  attr_accessor :raw_data_size

  def initialize(id = nil, uuid = nil, version = nil, path = nil, modification_date = nil, entries = nil, file_size = nil, raw_data_size = nil)
    @id = id
    @uuid = uuid
    @version = version
    @path = path
    @modification_date = modification_date
    @entries = entries
    @file_size = file_size
    @raw_data_size = raw_data_size
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}DatabankInfo
#   id - SOAP::SOAPString
#   name - SOAP::SOAPString
#   url - SOAP::SOAPString
#   script - SOAP::SOAPString
#   blastable - SOAP::SOAPBoolean
#   files - DatabaseClient::SOAP::MRS::Regular::FileInfo
class Databank
  attr_accessor :id
  attr_accessor :name
  attr_accessor :url
  attr_accessor :script
  attr_accessor :blastable
  attr_accessor :files

  def initialize(id = nil, name = nil, url = nil, script = nil, blastable = nil, files = [])
    @id = id
    @name = name
    @url = url
    @script = script
    @blastable = blastable
    @files = files
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}Index
#   id - SOAP::SOAPString
#   description - SOAP::SOAPString
#   count - SOAP::SOAPUnsignedLong
#   type - DatabaseClient::SOAP::MRS::Regular::IndexType
class Index
  attr_accessor :id
  attr_accessor :description
  attr_accessor :count
  attr_accessor :type

  def initialize(id = nil, description = nil, count = nil, type = nil)
    @id = id
    @description = description
    @count = count
    @type = type
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}Hit
#   db - SOAP::SOAPString
#   id - SOAP::SOAPString
#   title - SOAP::SOAPString
#   score - SOAP::SOAPFloat
class Hit
  attr_accessor :db
  attr_accessor :id
  attr_accessor :title
  attr_accessor :score

  def initialize(db = nil, id = nil, title = nil, score = nil)
    @db = db
    @id = id
    @title = title
    @score = score
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}FindAllResult
#   db - SOAP::SOAPString
#   count - SOAP::SOAPUnsignedLong
#   hits - DatabaseClient::SOAP::MRS::Regular::Hit
class Hits
  attr_accessor :db
  attr_accessor :count
  attr_accessor :hits

  def initialize(db = nil, count = nil, hits = [])
    @db = db
    @count = count
    @hits = hits
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}Format
class Format < ::String
  Fasta = Format.new("fasta")
  HTML = Format.new("html")
  Plain = Format.new("plain")
  Title = Format.new("title")
end

# {http://mrs.cmbi.ru.nl/mrsws}IndexType
class IndexType < ::String
  Date = IndexType.new("Date")
  FullText = IndexType.new("FullText")
  Number = IndexType.new("Number")
  Unique = IndexType.new("Unique")
end

# {http://mrs.cmbi.ru.nl/mrsws}Algorithm
class Algorithm < ::String
  Dice = Algorithm.new("Dice")
  Jaccard = Algorithm.new("Jaccard")
  Vector = Algorithm.new("Vector")
end

# {http://mrs.cmbi.ru.nl/mrsws}GetDatabankInfo
#   db - SOAP::SOAPString
class DatabankInfoParameters
  attr_accessor :db

  def initialize(db = nil)
    @db = db
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}GetDatabankInfoResponse
class DatabankInfoResponse < ::Array
end

# {http://mrs.cmbi.ru.nl/mrsws}GetEntry
#   db - SOAP::SOAPString
#   id - SOAP::SOAPString
#   format - DatabaseClient::SOAP::MRS::Regular::Format
class GetEntryParameters
  attr_accessor :db
  attr_accessor :id
  attr_accessor :format

  def initialize(db = nil, id = nil, format = nil)
    @db = db
    @id = id
    @format = format
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}GetEntryResponse
#   entry - SOAP::SOAPString
class GetEntryResponse
  attr_accessor :entry

  def initialize(entry = nil)
    @entry = entry
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}GetIndices
#   db - SOAP::SOAPString
class GetIndicesParameters
  attr_accessor :db

  def initialize(db = nil)
    @db = db
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}GetIndicesResponse
class GetIndicesResponse < ::Array
end

# {http://mrs.cmbi.ru.nl/mrsws}Find
#   db - SOAP::SOAPString
#   queryterms - SOAP::SOAPString
#   algorithm - DatabaseClient::SOAP::MRS::Regular::Algorithm
#   alltermsrequired - SOAP::SOAPBoolean
#   booleanfilter - SOAP::SOAPString
#   resultoffset - SOAP::SOAPInt
#   maxresultcount - SOAP::SOAPInt
class FindParameters
  attr_accessor :db
  attr_accessor :queryterms
  attr_accessor :algorithm
  attr_accessor :alltermsrequired
  attr_accessor :booleanfilter
  attr_accessor :resultoffset
  attr_accessor :maxresultcount

  def initialize(db = nil, queryterms = [], algorithm = nil, alltermsrequired = nil, booleanfilter = nil, resultoffset = nil, maxresultcount = nil)
    @db = db
    @queryterms = queryterms
    @algorithm = algorithm
    @alltermsrequired = alltermsrequired
    @booleanfilter = booleanfilter
    @resultoffset = resultoffset
    @maxresultcount = maxresultcount
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}FindResponse
#   count - SOAP::SOAPUnsignedLong
#   hits - DatabaseClient::SOAP::MRS::Regular::Hit
class FindResponse
  attr_accessor :count
  attr_accessor :hits

  def initialize(count = nil, hits = [])
    @count = count
    @hits = hits
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}FindSimilar
#   db - SOAP::SOAPString
#   id - SOAP::SOAPString
#   algorithm - DatabaseClient::SOAP::MRS::Regular::Algorithm
#   resultoffset - SOAP::SOAPInt
#   maxresultcount - SOAP::SOAPInt
class FindSimilarParameters
  attr_accessor :db
  attr_accessor :id
  attr_accessor :algorithm
  attr_accessor :resultoffset
  attr_accessor :maxresultcount

  def initialize(db = nil, id = nil, algorithm = nil, resultoffset = nil, maxresultcount = nil)
    @db = db
    @id = id
    @algorithm = algorithm
    @resultoffset = resultoffset
    @maxresultcount = maxresultcount
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}FindAll
#   queryterms - SOAP::SOAPString
#   algorithm - DatabaseClient::SOAP::MRS::Regular::Algorithm
#   alltermsrequired - SOAP::SOAPBoolean
#   booleanfilter - SOAP::SOAPString
class FindAllParameters
  attr_accessor :queryterms
  attr_accessor :algorithm
  attr_accessor :alltermsrequired
  attr_accessor :booleanfilter

  def initialize(queryterms = [], algorithm = nil, alltermsrequired = nil, booleanfilter = nil)
    @queryterms = queryterms
    @algorithm = algorithm
    @alltermsrequired = alltermsrequired
    @booleanfilter = booleanfilter
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}FindAllResponse
class FindAllResponse < ::Array
end

# {http://mrs.cmbi.ru.nl/mrsws}FindAllSimilar
#   db - SOAP::SOAPString
#   id - SOAP::SOAPString
#   algorithm - DatabaseClient::SOAP::MRS::Regular::Algorithm
class FindAllSimilarParameters
  attr_accessor :db
  attr_accessor :id
  attr_accessor :algorithm

  def initialize(db = nil, id = nil, algorithm = nil)
    @db = db
    @id = id
    @algorithm = algorithm
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}FindAllSimilarResponse
class FindAllSimilarResponse < ::Array
end

# {http://mrs.cmbi.ru.nl/mrsws}Count
#   db - SOAP::SOAPString
#   booleanquery - SOAP::SOAPString
class CountParameters
  attr_accessor :db
  attr_accessor :booleanquery

  def initialize(db = nil, booleanquery = nil)
    @db = db
    @booleanquery = booleanquery
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}CountResponse
#   response - SOAP::SOAPUnsignedLong
class CountResponse
  attr_accessor :response

  def initialize(response = nil)
    @response = response
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}Cooccurrence
#   db - SOAP::SOAPString
#   ids - SOAP::SOAPString
#   idf_cutoff - SOAP::SOAPFloat
#   resultoffset - SOAP::SOAPInt
#   maxresultcount - SOAP::SOAPInt
class CooccurrenceParameters
  attr_accessor :db
  attr_accessor :ids
  attr_accessor :idf_cutoff
  attr_accessor :resultoffset
  attr_accessor :maxresultcount

  def initialize(db = nil, ids = [], idf_cutoff = nil, resultoffset = nil, maxresultcount = nil)
    @db = db
    @ids = ids
    @idf_cutoff = idf_cutoff
    @resultoffset = resultoffset
    @maxresultcount = maxresultcount
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}CooccurrenceResponse
class CooccurrenceResponse < ::Array
end

# {http://mrs.cmbi.ru.nl/mrsws}SpellCheck
#   db - SOAP::SOAPString
#   queryterm - SOAP::SOAPString
class SpellCheckParameters
  attr_accessor :db
  attr_accessor :queryterm

  def initialize(db = nil, queryterm = nil)
    @db = db
    @queryterm = queryterm
  end
end

# {http://mrs.cmbi.ru.nl/mrsws}SpellCheckResponse
class SpellCheckResponse < ::Array
end

end
