#!/usr/bin/env ruby
#
# blast_driver.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/mrs/blast_mapping.rb'
require 'soap/rpc/driver'

module DatabaseClient::SOAP::MRS::BLAST

class Driver < ::SOAP::RPC::Driver
  DefaultEndpointUrl = "http://mrs.cmbi.ru.nl/mrsws-blast"

  Methods = [
    [ "",
      "blastSync",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastSync"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastResult"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "blastAsync",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastAsync"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastAsyncResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "blastJobStatus",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastJobStatus"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastJobStatusResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "blastJobResult",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastJobResult"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastResult"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ],
    [ "",
      "blastJobError",
      [ ["in", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastJobError"]],
        ["out", "parameters", ["::SOAP::SOAPElement", "http://mrs.cmbi.ru.nl/mrsws-blast", "BlastJobErrorResponse"]] ],
      { :request_style =>  :document, :request_use =>  :literal,
        :response_style => :document, :response_use => :literal,
        :faults => {} }
    ]
  ]

  def initialize(endpoint_url = nil)
    endpoint_url ||= DefaultEndpointUrl
    super(endpoint_url, nil)
    self.mapping_registry = Mapping::EncodedRegistry
    self.literal_mapping_registry = Mapping::LiteralRegistry
    init_methods
  end

private

  def init_methods
    Methods.each do |definitions|
      opt = definitions.last
      if opt[:request_style] == :document
        add_document_operation(*definitions)
      else
        add_rpc_operation(*definitions)
        qname = definitions[0]
        name = definitions[2]
        if qname.name != name and qname.name.capitalize == name.capitalize
          ::SOAP::Mapping.define_singleton_method(self, qname.name) do |*arg|
            __send__(name, *arg)
          end
        end
      end
    end
  end
end


end
