#!/usr/bin/env ruby
#
# blast_mapping.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/mrs/blast_types'
require 'soap/mapping'

module DatabaseClient::SOAP::MRS::BLAST

module Mapping
  EncodedRegistry = ::SOAP::Mapping::EncodedRegistry.new
  LiteralRegistry = ::SOAP::Mapping::LiteralRegistry.new
  NsMrswsBlast = "http://mrs.cmbi.ru.nl/mrsws-blast"

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Hsp,
    :schema_type => XSD::QName.new(NsMrswsBlast, "Hsp"),
    :schema_element => [
      ["score", "SOAP::SOAPUnsignedLong"],
      ["bit_score", ["SOAP::SOAPDouble", XSD::QName.new(NsMrswsBlast, "bit-score")]],
      ["expect", "SOAP::SOAPDouble"],
      ["query_start", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "query-start")]],
      ["subject_start", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "subject-start")]],
      ["identity", "SOAP::SOAPUnsignedLong"],
      ["positive", "SOAP::SOAPUnsignedLong"],
      ["gaps", "SOAP::SOAPUnsignedLong"],
      ["subject_length", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "subject-length")]],
      ["query_alignment", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "query-alignment")]],
      ["subject_alignment", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "subject-alignment")]],
      ["midline", "SOAP::SOAPString"]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Hit,
    :schema_type => XSD::QName.new(NsMrswsBlast, "Hit"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["title", "SOAP::SOAPString"],
      ["hsps", "DatabaseClient::SOAP::MRS::BLAST::Hsp[]", [0, nil]]
    ]
  )

  EncodedRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Status,
    :schema_type => XSD::QName.new(NsMrswsBlast, "JobStatus")
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Hsp,
    :schema_type => XSD::QName.new(NsMrswsBlast, "Hsp"),
    :schema_element => [
      ["score", "SOAP::SOAPUnsignedLong"],
      ["bit_score", ["SOAP::SOAPDouble", XSD::QName.new(NsMrswsBlast, "bit-score")]],
      ["expect", "SOAP::SOAPDouble"],
      ["query_start", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "query-start")]],
      ["subject_start", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "subject-start")]],
      ["identity", "SOAP::SOAPUnsignedLong"],
      ["positive", "SOAP::SOAPUnsignedLong"],
      ["gaps", "SOAP::SOAPUnsignedLong"],
      ["subject_length", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "subject-length")]],
      ["query_alignment", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "query-alignment")]],
      ["subject_alignment", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "subject-alignment")]],
      ["midline", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Hit,
    :schema_type => XSD::QName.new(NsMrswsBlast, "Hit"),
    :schema_element => [
      ["id", "SOAP::SOAPString"],
      ["title", "SOAP::SOAPString"],
      ["hsps", "DatabaseClient::SOAP::MRS::BLAST::Hsp[]", [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Status,
    :schema_type => XSD::QName.new(NsMrswsBlast, "JobStatus")
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::RunParameters,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastSync"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["mrsBooleanQuery", "SOAP::SOAPString"],
      ["query", "SOAP::SOAPString"],
      ["program", "SOAP::SOAPString"],
      ["matrix", "SOAP::SOAPString"],
      ["word_size", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "word-size")]],
      ["expect", "SOAP::SOAPDouble"],
      ["low_complexity_filter", ["SOAP::SOAPBoolean", XSD::QName.new(NsMrswsBlast, "low-complexity-filter")]],
      ["gapped", "SOAP::SOAPBoolean"],
      ["gap_open", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "gap-open")]],
      ["gap_extend", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "gap-extend")]],
      ["report_limit", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "report-limit")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::Result,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastResult"),
    :schema_element => [
      ["db_count", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "db-count")]],
      ["db_length", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "db-length")]],
      ["eff_space", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "eff-space")]],
      ["kappa", "SOAP::SOAPDouble"],
      ["lambda", "SOAP::SOAPDouble"],
      ["entropy", "SOAP::SOAPDouble"],
      ["hits", "DatabaseClient::SOAP::MRS::BLAST::Hit[]", [0, nil]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::StartParameters,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastAsync"),
    :schema_element => [
      ["db", "SOAP::SOAPString"],
      ["mrsBooleanQuery", "SOAP::SOAPString"],
      ["query", "SOAP::SOAPString"],
      ["program", "SOAP::SOAPString"],
      ["matrix", "SOAP::SOAPString"],
      ["word_size", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "word-size")]],
      ["expect", "SOAP::SOAPDouble"],
      ["low_complexity_filter", ["SOAP::SOAPBoolean", XSD::QName.new(NsMrswsBlast, "low-complexity-filter")]],
      ["gapped", "SOAP::SOAPBoolean"],
      ["gap_open", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "gap-open")]],
      ["gap_extend", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "gap-extend")]],
      ["report_limit", ["SOAP::SOAPUnsignedLong", XSD::QName.new(NsMrswsBlast, "report-limit")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::StartResponse,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastAsyncResponse"),
    :schema_element => [
      ["response", "SOAP::SOAPString"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::StatusParameters,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastJobStatus"),
    :schema_element => [
      ["job_id", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "job-id")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::StatusResponse,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastJobStatusResponse"),
    :schema_element => [
      ["response", "DatabaseClient::SOAP::MRS::BLAST::Status"]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::CollectParameters,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastJobResult"),
    :schema_element => [
      ["job_id", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "job-id")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::ErrorParameters,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastJobError"),
    :schema_element => [
      ["job_id", ["SOAP::SOAPString", XSD::QName.new(NsMrswsBlast, "job-id")]]
    ]
  )

  LiteralRegistry.register(
    :class => DatabaseClient::SOAP::MRS::BLAST::ErrorResponse,
    :schema_name => XSD::QName.new(NsMrswsBlast, "BlastJobErrorResponse"),
    :schema_element => [
      ["response", "SOAP::SOAPString"]
    ]
  )
end

end
