#!/usr/bin/env ruby
#
# blast_types.rb
# BioX Database Client
#
# Created by Erik Lagercrantz on 2008-02-14.
# Copyright 2008 Erik Lagercrantz.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

require 'ws/mrs/blast_main'
require 'xsd/qname'

module DatabaseClient::SOAP::MRS::BLAST

# {http://mrs.cmbi.ru.nl/mrsws-blast}Hsp
#   score - SOAP::SOAPUnsignedLong
#   bit_score - SOAP::SOAPDouble
#   expect - SOAP::SOAPDouble
#   query_start - SOAP::SOAPUnsignedLong
#   subject_start - SOAP::SOAPUnsignedLong
#   identity - SOAP::SOAPUnsignedLong
#   positive - SOAP::SOAPUnsignedLong
#   gaps - SOAP::SOAPUnsignedLong
#   subject_length - SOAP::SOAPUnsignedLong
#   query_alignment - SOAP::SOAPString
#   subject_alignment - SOAP::SOAPString
#   midline - SOAP::SOAPString
class Hsp
  attr_accessor :score
  attr_accessor :bit_score
  attr_accessor :expect
  attr_accessor :query_start
  attr_accessor :subject_start
  attr_accessor :identity
  attr_accessor :positive
  attr_accessor :gaps
  attr_accessor :subject_length
  attr_accessor :query_alignment
  attr_accessor :subject_alignment
  attr_accessor :midline

  def initialize(score = nil, bit_score = nil, expect = nil, query_start = nil, subject_start = nil, identity = nil, positive = nil, gaps = nil, subject_length = nil, query_alignment = nil, subject_alignment = nil, midline = nil)
    @score = score
    @bit_score = bit_score
    @expect = expect
    @query_start = query_start
    @subject_start = subject_start
    @identity = identity
    @positive = positive
    @gaps = gaps
    @subject_length = subject_length
    @query_alignment = query_alignment
    @subject_alignment = subject_alignment
    @midline = midline
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}Hit
#   id - SOAP::SOAPString
#   title - SOAP::SOAPString
#   hsps - DatabaseClient::SOAP::MRS::BLAST::Hsp
class Hit
  attr_accessor :id
  attr_accessor :title
  attr_accessor :hsps

  def initialize(id = nil, title = nil, hsps = [])
    @id = id
    @title = title
    @hsps = hsps
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastResult
#   db_count - SOAP::SOAPUnsignedLong
#   db_length - SOAP::SOAPUnsignedLong
#   eff_space - SOAP::SOAPUnsignedLong
#   kappa - SOAP::SOAPDouble
#   lambda - SOAP::SOAPDouble
#   entropy - SOAP::SOAPDouble
#   hits - DatabaseClient::SOAP::MRS::BLAST::Hit
class Result
  attr_accessor :db_count
  attr_accessor :db_length
  attr_accessor :eff_space
  attr_accessor :kappa
  attr_accessor :lambda
  attr_accessor :entropy
  attr_accessor :hits

  def initialize(db_count = nil, db_length = nil, eff_space = nil, kappa = nil, lambda = nil, entropy = nil, hits = [])
    @db_count = db_count
    @db_length = db_length
    @eff_space = eff_space
    @kappa = kappa
    @lambda = lambda
    @entropy = entropy
    @hits = hits
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastSync
#   db - SOAP::SOAPString
#   mrsBooleanQuery - SOAP::SOAPString
#   query - SOAP::SOAPString
#   program - SOAP::SOAPString
#   matrix - SOAP::SOAPString
#   word_size - SOAP::SOAPUnsignedLong
#   expect - SOAP::SOAPDouble
#   low_complexity_filter - SOAP::SOAPBoolean
#   gapped - SOAP::SOAPBoolean
#   gap_open - SOAP::SOAPUnsignedLong
#   gap_extend - SOAP::SOAPUnsignedLong
#   report_limit - SOAP::SOAPUnsignedLong
class RunParameters
  attr_accessor :db
  attr_accessor :mrsBooleanQuery
  attr_accessor :query
  attr_accessor :program
  attr_accessor :matrix
  attr_accessor :word_size
  attr_accessor :expect
  attr_accessor :low_complexity_filter
  attr_accessor :gapped
  attr_accessor :gap_open
  attr_accessor :gap_extend
  attr_accessor :report_limit

  def initialize(db = nil, mrsBooleanQuery = nil, query = nil, program = nil, matrix = nil, word_size = nil, expect = nil, low_complexity_filter = nil, gapped = nil, gap_open = nil, gap_extend = nil, report_limit = nil)
    @db = db
    @mrsBooleanQuery = mrsBooleanQuery
    @query = query
    @program = program
    @matrix = matrix
    @word_size = word_size
    @expect = expect
    @low_complexity_filter = low_complexity_filter
    @gapped = gapped
    @gap_open = gap_open
    @gap_extend = gap_extend
    @report_limit = report_limit
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastAsync
#   db - SOAP::SOAPString
#   mrsBooleanQuery - SOAP::SOAPString
#   query - SOAP::SOAPString
#   program - SOAP::SOAPString
#   matrix - SOAP::SOAPString
#   word_size - SOAP::SOAPUnsignedLong
#   expect - SOAP::SOAPDouble
#   low_complexity_filter - SOAP::SOAPBoolean
#   gapped - SOAP::SOAPBoolean
#   gap_open - SOAP::SOAPUnsignedLong
#   gap_extend - SOAP::SOAPUnsignedLong
#   report_limit - SOAP::SOAPUnsignedLong
class StartParameters
  attr_accessor :db
  attr_accessor :mrsBooleanQuery
  attr_accessor :query
  attr_accessor :program
  attr_accessor :matrix
  attr_accessor :word_size
  attr_accessor :expect
  attr_accessor :low_complexity_filter
  attr_accessor :gapped
  attr_accessor :gap_open
  attr_accessor :gap_extend
  attr_accessor :report_limit

  def initialize(db = nil, mrsBooleanQuery = nil, query = nil, program = nil, matrix = nil, word_size = nil, expect = nil, low_complexity_filter = nil, gapped = nil, gap_open = nil, gap_extend = nil, report_limit = nil)
    @db = db
    @mrsBooleanQuery = mrsBooleanQuery
    @query = query
    @program = program
    @matrix = matrix
    @word_size = word_size
    @expect = expect
    @low_complexity_filter = low_complexity_filter
    @gapped = gapped
    @gap_open = gap_open
    @gap_extend = gap_extend
    @report_limit = report_limit
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastAsyncResponse
#   response - SOAP::SOAPString
class StartResponse
  attr_accessor :response

  def initialize(response = nil)
    @response = response
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastJobResult
#   job_id - SOAP::SOAPString
class CollectParameters
  attr_accessor :job_id

  def initialize(job_id = nil)
    @job_id = job_id
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastJobStatus
#   job_id - SOAP::SOAPString
class StatusParameters
  attr_accessor :job_id

  def initialize(job_id = nil)
    @job_id = job_id
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}JobStatus
class Status < ::String
  Error = Status.new("error")
  Finished = Status.new("finished")
  Queued = Status.new("queued")
  Running = Status.new("running")
  Unknown = Status.new("unknown")
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastJobStatusResponse
#   response - DatabaseClient::SOAP::MRS::BLAST::JobStatus
class StatusResponse
  attr_accessor :response

  def initialize(response = nil)
    @response = response
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastJobError
#   job_id - SOAP::SOAPString
class ErrorParameters
  attr_accessor :job_id

  def initialize(job_id = nil)
    @job_id = job_id
  end
end

# {http://mrs.cmbi.ru.nl/mrsws-blast}BlastJobErrorResponse
#   response - SOAP::SOAPString
class ErrorResponse
  attr_accessor :response

  def initialize(response = nil)
    @response = response
  end
end

end
