# MRS plugin for creating a db
#
# $Id: uniseq.pm 169 2006-11-10 08:02:05Z hekkel $
#
# Copyright (c) 2005
#      CMBI, Radboud University Nijmegen. All rights reserved.
#
# This code is derived from software contributed by Maarten L. Hekkelman
# and Hekkelman Programmatuur b.v. Modified by Erik Lagercrantz.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgement:
#        This product includes software developed by the Radboud University
#        Nijmegen and its contributors.
# 4. Neither the name of Radboud University nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE RADBOUD UNIVERSITY AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE UNIVERSITY OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

package MRS::Script::fasta;

our @ISA = "MRS::Script";

sub new
{
	my $invocant = shift;

	my $self = {
		name		=> "eBioX Custom Database",
		url			=> "http://www.ebioinformatics.org/ebiox",
		meta		=> [ 'title' ],
		section		=> "unknown",
		@_
	};
	
	return bless $self, "MRS::Script::fasta";
}

sub parse
{
	my $self = shift;
	local *IN = shift;
	
	my ($doc, $m);
	
	$m = $self->{mrs};
	
	while (my $line = <IN>)
	{
		if ($line =~ m/>\s*(\S+)(\s+(\S+.*)?)?/)
		{
			$idpart = $1;
			$descpart = $3;
			
			if (defined $doc)
			{
				$m->Store($doc);
				$m->FlushDocument;
			}

			$doc = $line;

			@splitid = split(/\|/, $idpart);

			$m->IndexValue('id', $splitid[-1]); print $splitid[-1]."\n";
			$m->StoreMetaData('title', substr($3, 0, 255));
			$m->IndexText('title', $3);
		}
		else
		{
			$doc .= $line;
		}
	}
	
	if (defined $doc)
	{
		$m->Store($doc);
		$m->FlushDocument;
	}
}

1;
