# $Id: uniprot.pm 151 2006-10-31 09:03:08Z hekkel $
#
# Copyright (c) 2005
#      CMBI, Radboud University Nijmegen. All rights reserved.
#
# This code is derived from software contributed by Maarten L. Hekkelman
# and Hekkelman Programmatuur b.v. Modified by Erik Lagercrantz.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgement:
#        This product includes software developed by the Radboud University
#        Nijmegen and its contributors.
# 4. Neither the name of Radboud University nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE RADBOUD UNIVERSITY AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE UNIVERSITY OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#

package MRS::Script::uniprot;

our @ISA = "MRS::Script";

use strict;

my $commentLine1 = "CC   -----------------------------------------------------------------------";
my $commentLine2 = "CC   Copyrighted by the UniProt Consortium, see http://www.uniprot.org/terms";
my $commentLine3 = "CC   Distributed under the Creative Commons Attribution-NoDerivs License";

sub new
{
	my $invocant = shift;

	my $self = {
		name					=> "eBioX Custom Database",
		url						=> "http://www.ebioinformatics.org/ebiox",
		meta					=> [ 'title' ],
		section					=> "protein",
		@_
	};
	
	return bless $self, "MRS::Script::uniprot";
}

sub parse
{
	my $self = shift;
	local *IN = shift;
	my ($verbose, $db) = @_;
	
	my ($id, $doc, $title, $species, $m);
	
	$m = $self->{mrs};
	
	while (my $line = <IN>)
	{
		$doc .= $line;

		chomp($line);

		# just maybe there are records without a sequence???
		if ($line eq '//')
		{
			$m->StoreMetaData('title', $title)		if defined $title;
#			$m->StoreMetaData('species', $species)	if defined $species;
			$m->Store($doc);
			$m->FlushDocument;
	
			$id = undef;
			$doc = undef;
			$title = undef;
			$species = undef;
		}
		elsif ($line =~ /^([A-Z]{2}) {3}(.+)/o)
		{
			my $fld = $1;
			my $value = $2;

			if ($line =~ /^ID +(\S+)/o)
			{
				$id = $1;
				$m->IndexValue('id', $id);
			}
			elsif ($fld eq 'SQ')
			{
				if ($line =~ /SEQUENCE\s+(\d+) AA;\s+(\d+) MW;\s+([0-9A-F]{16}) CRC64;/o)
				{
					$m->IndexNumber('length', $1);
					$m->IndexNumber('mw', $2);
					$m->IndexWord('crc64', $3);
				}
				
				while ($line = <IN>)
				{
					$doc .= $line;
					chomp($line);

					last if $line eq '//';
				}

				$m->StoreMetaData('title', $title)		if defined $title;
#				$m->StoreMetaData('species', $species)	if defined $species;
				$m->Store($doc);
				$m->FlushDocument;
	
				$id = undef;
				$doc = undef;
				$title = undef;
				$species = undef;
			}
			elsif (substr($fld, 0, 1) eq 'R')
			{
				$m->IndexTextAndNumbers('ref', $value);
			}
			elsif ($fld eq 'CC')
			{
				if ($line ne $commentLine1 and
					$line ne $commentLine2 and
					$line ne $commentLine3)
				{
					$m->IndexTextAndNumbers('cc', $value);
				}
			}
			elsif ($fld eq 'DE')
			{
				$title .= ' ' if defined $title;
				$title .= $value;
				
				$m->IndexTextAndNumbers('de', $value);
			}
			elsif ($fld eq 'OS')
			{
				$species .= ' ' if defined $species;
				$species .= $value;
				
				$m->IndexTextAndNumbers('os', $value);
			}
			elsif ($fld ne 'XX')
			{
				$m->IndexTextAndNumbers(lc($fld), $value);
			}
		}
	}
}

1;
